@@ -4,7 +4,7 @@ import os
 import cStringIO as StringIO
 
 from subprocess import Popen, PIPE
-from pymatgen.util.io_utils import which
+from monty.os.path import which
 from pymatgen.util.string_utils import list_strings
 
 import logging
@@ -36,7 +36,7 @@ class ExecWrapper(object):
             verbose:
                 Verbosity level.
         """
-        if executable is None: 
+        if executable is None:
             executable = self.name
 
         self.executable = which(executable)
@@ -52,14 +52,40 @@ class ExecWrapper(object):
     def __str__(self):
         return "%s" % self.executable
 
+    def set_mpi_runner(self, mpi_runner="mpirun"):
+        # TODO better treatment of mpirunner syntax.
+        self._mpi_runner = mpi_runner
+
+    @property
+    def mpi_runner(self):
+        try:
+            return self._mpi_runner
+
+        except AttributeError:
+            return ""
+
     @property
     def name(self):
         return self._name
 
-    def execute(self, cwd=None, **kwargs):
-        """Execute the executable in a subprocess."""
+    def execute(self, cwd=None):
+
+        # Try to execute binary without and with mpirun.
+        try:
+            self._execute(cwd=cwd, with_mpirun=False)
+
+        except self.Error:
+            self._execute(cwd=cwd, with_mpirun=True)
+
+    def _execute(self, cwd=None, with_mpirun=False):
+        """
+        Execute the executable in a subprocess.
+        """
         args = [self.executable, "<", self.stdin_fname, ">", self.stdout_fname, "2>", self.stderr_fname]
 
+        if self.mpi_runner and with_mpirun:
+            args.insert(0, self.mpi_runner)
+
         self.cmd_str = " ".join(args)
 
         p = Popen(self.cmd_str, shell=True, stdout=PIPE, stderr=PIPE, cwd=cwd)
@@ -116,7 +142,7 @@ class Mrgscr(ExecWrapper):
 
         inp = StringIO.StringIO()
 
-        inp.write(str(nfiles) + "\n")      # Number of files to merge.
+        inp.write(str(nfiles) + "\n")     # Number of files to merge.
         inp.write(out_prefix + "\n")      # Prefix for the final output file:
 
         for filename in files_to_merge:
@@ -150,7 +176,7 @@ class Mrggkk(ExecWrapper):
         Merge GGK files, return the absolute path of the new database.
 
         Args:
-            gswfk_file: 
+            gswfk_file:
                 Ground-state WFK filename
             dfpt_files:
                 List of 1WFK files to merge.
@@ -176,10 +202,10 @@ class Mrggkk(ExecWrapper):
             print("Will merge %d 1WF files, %d GKK file in output %s" %
                   (len(dfpt_nfiles), (len_gkk_files), out_gkk))
 
-            for (i, f) in enumerate(dfpt_files): 
+            for (i, f) in enumerate(dfpt_files):
                 print(" [%d] 1WF %s" % (i, f))
 
-            for (i, f) in enumerate(gkk_files):  
+            for (i, f) in enumerate(gkk_files):
                 print(" [%d] GKK %s" % (i, f))
 
         self.stdin_fname, self.stdout_fname, self.stderr_fname = (
@@ -200,11 +226,11 @@ class Mrggkk(ExecWrapper):
         inp.write(dims + "\n")             # Number of 1WF, of GKK files, and number of 1WF files in all the GKK files
 
         # Names of the 1WF files...
-        for fname in dfpt_files: 
+        for fname in dfpt_files:
             inp.write(fname + "\n")
 
         # Names of the GKK files...
-        for fname in gkk_files: 
+        for fname in gkk_files:
             inp.write(fname + "\n")
 
         inp.seek(0)
