@@ -39,6 +39,8 @@ __email__ = "shyuep@gmail.com"
 __date__ = "Apr 30, 2012"
 
 import json
+import numpy as np
+
 from abc import ABCMeta, abstractproperty
 import datetime
 
@@ -120,6 +122,11 @@ class PMGJSONEncoder(json.JSONEncoder):
                 return {"@module": "datetime",
                         "@class": "datetime",
                         "string": str(o)}
+            elif isinstance(o, np.ndarray):
+                return o.tolist()
+            elif isinstance(o, np.generic):
+                return o.item()
+
             d = o.to_dict
             if "@module" not in d:
                 d["@module"] = o.__class__.__module__
@@ -180,6 +187,7 @@ class PMGJSONDecoder(json.JSONDecoder):
                     for k, v in d.items()}
         elif isinstance(d, list):
             return [self.process_decoded(x) for x in d]
+
         return d
 
     def decode(self, s):
@@ -203,14 +211,6 @@ def json_pretty_dump(obj, filename):
         json.dump(obj, fh, indent=4, sort_keys=4)
 
 
-def json_load(filename):
-    """
-    Deserialize a file containing a JSON document to a Python object.
-    """
-    with open(filename, "r") as fh:
-        return json.load(fh)
-
-
 def pmg_load(filename, **kwargs):
     """
     Loads a json file and deserialize it with PMGJSONDecoder.
