@@ -17,6 +17,8 @@ __date__ = "Nov 27, 2011"
 
 import numpy as np
 import math
+from monty.dev import deprecated
+from pymatgen.core.lattice import Lattice
 
 
 def find_in_coord_list(coord_list, coord, atol=1e-8):
@@ -58,10 +60,10 @@ def is_coord_subset(subset, superset, atol=1e-8):
     """
     Tests if all coords in subset are contained in superset.
     Doesn't use periodic boundary conditions
-    
+
     Args:
         subset, superset: List of coords
-        
+
     Returns:
         True if all of subset is in superset.
     """
@@ -76,10 +78,10 @@ def coord_list_mapping(subset, superset):
     """
     Gives the index mapping from a subset to a superset.
     Subset and superset cannot contain duplicate rows
-    
+
     Args:
         subset, superset: List of coords
-        
+
     Returns:
         list of indices such that superset[indices] = subset
     """
@@ -101,20 +103,20 @@ def coord_list_mapping_pbc(subset, superset, atol=1e-8):
     """
     Gives the index mapping from a subset to a superset.
     Subset and superset cannot contain duplicate rows
-    
+
     Args:
         subset, superset: List of frac_coords
-        
+
     Returns:
         list of indices such that superset[indices] = subset
     """
     c1 = np.array(subset)
     c2 = np.array(superset)
-    
+
     diff = c1[:, None, :] - c2[None, :, :]
     diff -= np.round(diff)
     inds = np.where(np.all(np.abs(diff) < atol, axis = 2))[1]
-    
+
     #verify result (its easier to check validity of the result than
     #the validity of inputs)
     test = c2[inds] - c1
@@ -158,10 +160,10 @@ def get_linear_interpolated_value(x_values, y_values, x):
 
 def all_distances(coords1, coords2):
     """
-    Returns the distances between two lists of coordinates 
+    Returns the distances between two lists of coordinates
 
     Args:
-        coords1: First set of cartesian coordinates. 
+        coords1: First set of cartesian coordinates.
         coords2: Second set of cartesian coordinates.
 
     Returns:
@@ -195,6 +197,7 @@ def pbc_diff(fcoords1, fcoords2):
     return fdist - np.round(fdist)
 
 
+@deprecated(Lattice.get_all_distances)
 def pbc_all_distances(lattice, fcoords1, fcoords2):
     """
     Returns the distances between two lists of coordinates taking into
@@ -214,36 +217,7 @@ def pbc_all_distances(lattice, fcoords1, fcoords2):
         2d array of cartesian distances. E.g the distance between
         fcoords1[i] and fcoords2[j] is distances[i,j]
     """
-    #ensure correct shape
-    fcoords1, fcoords2 = np.atleast_2d(fcoords1, fcoords2)
-
-    #ensure that all points are in the unit cell
-    fcoords1 = np.mod(fcoords1, 1)
-    fcoords2 = np.mod(fcoords2, 1)
-
-    #create images, 2d array of all length 3 combinations of [-1,0,1]
-    r = np.arange(-1, 2)
-    arange = r[:, None] * np.array([1, 0, 0])[None, :]
-    brange = r[:, None] * np.array([0, 1, 0])[None, :]
-    crange = r[:, None] * np.array([0, 0, 1])[None, :]
-    images = arange[:, None, None] + brange[None, :, None] +\
-        crange[None, None, :]
-    images = images.reshape((27, 3))
-
-    #create images of f2
-    shifted_f2 = fcoords2[:, None, :] + images[None, :, :]
-
-    cart_f1 = lattice.get_cartesian_coords(fcoords1)
-    cart_f2 = lattice.get_cartesian_coords(shifted_f2)
-
-    #all vectors from f1 to f2
-    vectors = cart_f2[None, :, :, :] - cart_f1[:, None, None, :]
-
-    d_2 = np.sum(vectors ** 2, axis=3)
-
-    distances = np.min(d_2, axis=2) ** 0.5
-
-    return distances
+    return lattice.get_all_distances(fcoords1, fcoords2)
 
 
 def pbc_shortest_vectors(lattice, fcoords1, fcoords2):
@@ -332,10 +306,10 @@ def in_coord_list_pbc(fcoord_list, fcoord, atol=1e-8):
 def is_coord_subset_pbc(subset, superset, atol=1e-8):
     """
     Tests if all fractional coords in subset are contained in superset.
-    
+
     Args:
         subset, superset: List of fractional coords
-        
+
     Returns:
         True if all of subset is in superset.
     """
@@ -348,6 +322,7 @@ def is_coord_subset_pbc(subset, superset, atol=1e-8):
     return np.all(any_close)
 
 
+@deprecated(Lattice.get_points_in_sphere)
 def get_points_in_sphere_pbc(lattice, frac_points, center, r):
     """
     Find all points within a sphere from the point taking into account
@@ -375,51 +350,18 @@ def get_points_in_sphere_pbc(lattice, frac_points, center, r):
         [(fcoord, dist) ...] since most of the time, subsequent processing
         requires the distance.
     """
-    recp_len = np.array(lattice.reciprocal_lattice.abc)
-    sr = r + 0.15
-    nmax = sr * recp_len / (2 * math.pi)
-    pcoords = lattice.get_fractional_coords(center)
-    floor = math.floor
-
-    n = len(frac_points)
-    fcoords = np.array(frac_points)
-    pts = np.tile(center, (n, 1))
-    indices = np.array(range(n))
-
-    arange = np.arange(start=int(floor(pcoords[0] - nmax[0])),
-                       stop=int(floor(pcoords[0] + nmax[0])) + 1)
-    brange = np.arange(start=int(floor(pcoords[1] - nmax[1])),
-                       stop=int(floor(pcoords[1] + nmax[1])) + 1)
-    crange = np.arange(start=int(floor(pcoords[2] - nmax[2])),
-                       stop=int(floor(pcoords[2] + nmax[2])) + 1)
-
-    arange = arange[:, None] * np.array([1, 0, 0])[None, :]
-    brange = brange[:, None] * np.array([0, 1, 0])[None, :]
-    crange = crange[:, None] * np.array([0, 0, 1])[None, :]
-
-    images = arange[:, None, None] + brange[None, :, None] +\
-        crange[None, None, :]
-
-    shifted_coords = fcoords[:, None, None, None, :] + images[None, :, :, :, :]
-    coords = lattice.get_cartesian_coords(shifted_coords)
-    dists = np.sqrt(np.sum((coords - pts[:, None, None, None, :]) ** 2,
-                           axis=4))
-    within_r = np.where(dists <= r)
-
-    d = [shifted_coords[within_r], dists[within_r], indices[within_r[0]]]
-
-    return np.transpose(d)
+    return lattice.get_points_in_sphere(frac_points, center, r)
 
 
 def lattice_points_in_supercell(supercell_matrix):
     """
     Returns the list of points on the original lattice contained in the
     supercell in fractional coordinates (with the supercell basis).
-    e.g. [[2,0,0],[0,1,0],[0,0,1]] returns [[0,0,0],[0.5,0,0]] 
-    
+    e.g. [[2,0,0],[0,1,0],[0,0,1]] returns [[0,0,0],[0.5,0,0]]
+
     Args:
         supercell_matrix: 3x3 matrix describing the supercell
-        
+
     Returns:
         numpy array of the fractional coordinates
     """
